# Supported Services

gcp-pilot supports a wide range of Google Cloud Platform services. Each service has its own dedicated documentation page with detailed usage examples.

## Core Services

- [IAM](iam.md) - Identity and Access Management
- [Identity Platform](identity_platform.md) - User authentication and identity management
- [Resource Manager](resource.md) - Project and resource management
- [Secret Manager](secret_manager.md) - Secret storage and management
- [Identity Aware Proxy](iap.md) - Secure access to applications

## Storage and Databases

- [Cloud Storage](storage.md) - Object storage
- [Cloud SQL](sql.md) - Managed relational database service
- [Datastore](datastore.md) - NoSQL document database
- [BigQuery](big_query.md) - Serverless data warehouse

## Compute and Serverless

- [Cloud Functions](functions.md) - Serverless functions
- [Cloud Run](run.md) - Serverless container platform
- [App Engine](app_engine.md) - Fully managed platform

## Messaging and Integration

- [Pub/Sub](pubsub.md) - Messaging and event streaming
- [Cloud Tasks](tasks.md) - Asynchronous task execution
- [Cloud Scheduler](scheduler.md) - Managed cron job service

## DevOps and CI/CD

- [Cloud Build](build.md) - Continuous integration and delivery platform
- [Source Repositories](source.md) - Git repository hosting

## Networking

- [Cloud DNS](dns.md) - Domain name system service
- [API Gateway](api_gateway.md) - API management platform

## Monitoring and Logging

- [Error Reporting](error_reporting.md) - Error tracking and reporting
- [Logging](logging.md) - Logging service
- [Monitoring](monitoring.md) - Infrastructure and application monitoring

## Specialized Services

- [Healthcare](healthcare.md) - Healthcare data management
- [Speech](speech.md) - Speech recognition and transcription
- [Datastream](datastream.md) - Database migration and replication

## Google Workspace Integration

- [Directory](directory.md) - User and group management
- [Calendar](calendar.md) - Calendar management
- [Sheets](sheets.md) - Spreadsheet management
- [People](people.md) - Contacts management
- [Chats](chats.md) - Chat messaging